Documentation
¶
Overview ¶
* Copyright (c) KylinSoft Co., Ltd. 2024.All rights reserved. * PilotGo-plugin-topology licensed under the Mulan Permissive Software License, Version 2. * See LICENSE file for more details. * Author: Wangjunqi123 <wangjunqi@kylinos.cn> * Date: Mon Nov 4 14:30:13 2024 +0800
* Copyright (c) KylinSoft Co., Ltd. 2024.All rights reserved. * PilotGo-plugin-topology licensed under the Mulan Permissive Software License, Version 2. * See LICENSE file for more details. * Author: Wangjunqi123 <wangjunqi@kylinos.cn> * Date: Mon Nov 4 14:30:13 2024 +0800
Index ¶
Constants ¶
const (
DOCKER_CONFIG = "/etc/docker/daemon.json"
)
Variables ¶
var DOCKERD_PORT = ""
Functions ¶
func ContainerList ¶
func ContainerList() ([]docker.APIContainers, error)
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.