webserver

package
v1.0.4-0...-d8282c0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 24, 2025 License: MulanPSL-2.0 Imports: 13 Imported by: 0

Documentation

Overview

* Copyright (c) KylinSoft Co., Ltd. 2024.All rights reserved. * PilotGo-plugin-topology licensed under the Mulan Permissive Software License, Version 2. * See LICENSE file for more details. * Author: Wangjunqi123 <wangjunqi@kylinos.cn> * Date: Fri Nov 8 09:13:05 2024 +0800

* Copyright (c) KylinSoft Co., Ltd. 2024.All rights reserved. * PilotGo-plugin-topology licensed under the Mulan Permissive Software License, Version 2. * See LICENSE file for more details. * Author: Wangjunqi123 <wangjunqi@kylinos.cn> * Date: Fri Nov 8 09:13:05 2024 +0800

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ContainerListHandle

func ContainerListHandle(ctx *gin.Context)

func HealthCheckHandle

func HealthCheckHandle(ctx *gin.Context)

func InitRouter

func InitRouter(router *gin.Engine)

func InitWebServer

func InitWebServer()

func RawMetricDataHandle

func RawMetricDataHandle(ctx *gin.Context)

Types

This section is empty.

Directories

Path Synopsis
* Copyright (c) KylinSoft Co., Ltd.
* Copyright (c) KylinSoft Co., Ltd.

Jump to