influxmanager

package
v1.0.4-0...-d8282c0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 24, 2025 License: MulanPSL-2.0 Imports: 7 Imported by: 0

Documentation

Overview

* Copyright (c) KylinSoft Co., Ltd. 2024.All rights reserved. * PilotGo-plugin-topology licensed under the Mulan Permissive Software License, Version 2. * See LICENSE file for more details. * Author: Wangjunqi123 <wangjunqi@kylinos.cn> * Date: Mon Nov 4 14:30:13 2024 +0800

* Copyright (c) KylinSoft Co., Ltd. 2024.All rights reserved. * PilotGo-plugin-topology licensed under the Mulan Permissive Software License, Version 2. * See LICENSE file for more details. * Author: Wangjunqi123 <wangjunqi@kylinos.cn> * Date: Mon Nov 4 14:30:13 2024 +0800

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type InfluxClient

type InfluxClient struct {
	ServerURL    string
	Token        string
	Organization string
	Bucket       string

	Client influx.Client
}
var Global_Influx *InfluxClient

func InfluxdbInit

func InfluxdbInit(conf *conf.InfluxConf) *InfluxClient

func (*InfluxClient) Query

func (i *InfluxClient) Query(measurement, start, end string) error

func (*InfluxClient) WriteWithLineProtocol

func (i *InfluxClient) WriteWithLineProtocol(measurement string, tags map[string]string, fields map[string]interface{}) error

Jump to