Documentation
¶
Overview ¶
* Copyright (c) KylinSoft Co., Ltd. 2024.All rights reserved. * PilotGo-plugin-topology licensed under the Mulan Permissive Software License, Version 2. * See LICENSE file for more details. * Author: Wangjunqi123 <wangjunqi@kylinos.cn> * Date: Mon Nov 4 14:30:13 2024 +0800
* Copyright (c) KylinSoft Co., Ltd. 2024.All rights reserved. * PilotGo-plugin-topology licensed under the Mulan Permissive Software License, Version 2. * See LICENSE file for more details. * Author: Wangjunqi123 <wangjunqi@kylinos.cn> * Date: Mon Nov 4 14:30:13 2024 +0800
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Prometheus ¶
var Global_Prome *Prometheus
func CreatePrometheus ¶
func CreatePrometheus(url string) *Prometheus
func (*Prometheus) CreateAPI ¶
func (p *Prometheus) CreateAPI() error
func (*Prometheus) GetMetrics ¶
func (p *Prometheus) GetMetrics() ([]string, error)
func (*Prometheus) GetTargets ¶
func (p *Prometheus) GetTargets() ([]map[string]string, error)
Click to show internal directories.
Click to hide internal directories.