Documentation
¶
Overview ¶
* Copyright (c) KylinSoft Co., Ltd. 2024.All rights reserved. * PilotGo-plugin-topology licensed under the Mulan Permissive Software License, Version 2. * See LICENSE file for more details. * Author: Wangjunqi123 <wangjunqi@kylinos.cn> * Date: Mon Nov 4 14:30:13 2024 +0800
* Copyright (c) KylinSoft Co., Ltd. 2024.All rights reserved. * PilotGo-plugin-topology licensed under the Mulan Permissive Software License, Version 2. * See LICENSE file for more details. * Author: Wangjunqi123 <wangjunqi@kylinos.cn> * Date: Mon Nov 4 14:30:13 2024 +0800
Index ¶
Constants ¶
const Version = "1.0.1"
Variables ¶
var Global_Client *client.Client
var PluginInfo = &client.PluginInfo{ Name: "topology", Version: Version, Description: "System application architecture detection.", Author: "wangjunqi", Email: "wangjunqi@kylinos.cn", Url: "", Icon: "Help", MenuName: "集群拓扑", PluginType: "micro-app", }
Functions ¶
func InitPluginClient ¶
func InitPluginClient()
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.